@@ -1,5 +1,5 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys.c 17449 2017-01-16 21:27:04Z pwessel $
+ *	$Id: x2sys.c 18145 2017-05-06 04:40:01Z pwessel $
  *
  *      Copyright (c) 1999-2017 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
@@ -104,9 +104,11 @@
  *--------------------------------------------------------------------------------
  */
 
-#include "x2sys.h"
-#include "gmt_internals.h"
+#include "gmt_dev.h"
 #include "common_byteswap.h"
+#include "gmt_internals.h"
+#include "mgd77/mgd77.h"
+#include "x2sys.h"
 
 /* Global variables used by X2SYS functions */
 
@@ -210,7 +212,7 @@ void x2sys_set_home (struct GMT_CTRL *GMT) {
 	}
 	else {	/* Require user to set this parameters since subdirs will be created and it would be messy to just use . */
 		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: %s has not been set but is a required parameter\n", par);
-		exit (GMT_RUNTIME_ERROR);
+		GMT_exit (GMT, GMT_RUNTIME_ERROR);
 	}
 #ifdef WIN32
 		gmt_dos_path_fix (X2SYS_HOME);
@@ -263,14 +265,14 @@ void x2sys_skip_header (struct GMT_CTRL *GMT, FILE *fp, struct X2SYS_INFO *s) {
 		for (i = 0; i < s->skip; i++) {
 			if (!fgets (line, GMT_BUFSIZ, fp)) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Read error in header line %d\n", i);
-				exit (GMT_DATA_READ_ERROR);
+				GMT_exit (GMT, GMT_DATA_READ_ERROR);
 			}
 		}
 	}
 	else if (s->file_type == X2SYS_BINARY) {			/* Native binary, skip bytes */
 		if (fseek (fp, (off_t)s->skip, SEEK_CUR)) {
 			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Seed error while skipping headers\n");
-			exit (GMT_DATA_READ_ERROR);
+			GMT_exit (GMT,GMT_DATA_READ_ERROR);
 		}
 	}
 }
@@ -1085,8 +1087,8 @@ int x2sys_set_system (struct GMT_CTRL *GMT, char *TAG, struct X2SYS_INFO **S, st
 			switch (p[1]) {
 				/* Common parameters */
 				case 'R':	/* Must be smart enough to deal with any command-line -R setting also given by user */
-					if (GMT->common.R.active) {	/* Have already parsed a command line setting */
-						parsed_command_R = true;	GMT->common.R.active = false;	/* Set to false so 2nd parse will work */
+					if (GMT->common.R.active[RSET]) {	/* Have already parsed a command line setting */
+						parsed_command_R = true;	GMT->common.R.active[RSET] = false;	/* Set to false so 2nd parse will work */
 						gmt_M_memcpy (save_R_wesn, GMT->common.R.wesn, 4, double);	/* Save command-line -R values */
 					}
 					if (gmt_parse_common_options (GMT, "R", 'R', &p[2])) {
@@ -1096,7 +1098,7 @@ int x2sys_set_system (struct GMT_CTRL *GMT, char *TAG, struct X2SYS_INFO **S, st
 					}
 					gmt_M_memcpy (B->wesn, GMT->common.R.wesn, 4, double);
 					if (parsed_command_R) gmt_M_memcpy (GMT->common.R.wesn, save_R_wesn, 4, double);	/* Restore command-line -R values */
-					GMT->common.R.active = parsed_command_R;	/* Only true if command-line -R was parsed, not this tag file */
+					GMT->common.R.active[RSET] = parsed_command_R;	/* Only true if command-line -R was parsed, not this tag file */
 					break;
 
 				case 'M':	/* GMT4 Backwards compatibility */
@@ -1624,7 +1626,8 @@ uint64_t x2sys_read_coe_dbase (struct GMT_CTRL *GMT, struct X2SYS_INFO *S, char
 	fp = stdin;	/* Default to stdin if dbase is NULL */
 	if (dbase && (fp = fopen (dbase, "r")) == NULL) {
 		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: Unable to open crossover file %s\n", dbase);
-		exit (GMT_ERROR_ON_FOPEN);
+		*nx = 0;
+		return 0;
 	}
 
 	n_alloc_p = n_alloc_t = GMT_CHUNK;
@@ -1641,7 +1644,7 @@ uint64_t x2sys_read_coe_dbase (struct GMT_CTRL *GMT, struct X2SYS_INFO *S, char
 		if (!strncmp (line, "# Tag:", 6)) {	/* Found the # TAG record */
 			if (strcmp (S->TAG, &line[7])) {	/* -Ttag and this TAG do not match */
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: Crossover file %s has a tag (%s) that differs from specified tag (%s) - aborting\n", dbase, &line[7], S->TAG);
-				exit (GMT_RUNTIME_ERROR);
+				GMT_exit (GMT, GMT_RUNTIME_ERROR);
 			}
 			continue;	/* Goto next record */
 		}
@@ -1673,12 +1676,12 @@ uint64_t x2sys_read_coe_dbase (struct GMT_CTRL *GMT, struct X2SYS_INFO *S, char
 	our_item -= 10;		/* Account for the 10 common items */
 	if (our_item < 0) {
 		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: Crossover file %s does not have the specified column %s - aborting\n", dbase, fflag);
-		exit (GMT_RUNTIME_ERROR);
+		GMT_exit (GMT, GMT_RUNTIME_ERROR);
 	}
 
 	if (ignorefile && (k = x2sys_read_list (GMT, ignorefile, &ignore, &n_ignore)) != X2SYS_NOERROR) {
 		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: Ignore file %s cannot be read - aborting\n", ignorefile);
-		exit (GMT_RUNTIME_ERROR);
+		GMT_exit (GMT, GMT_RUNTIME_ERROR);
 	}
 
 	check_box = (wesn && !(wesn[XLO] == wesn[XHI] && wesn[YLO] == wesn[YHI]));	/* Specified a rectangular box */
@@ -1701,7 +1704,7 @@ uint64_t x2sys_read_coe_dbase (struct GMT_CTRL *GMT, struct X2SYS_INFO *S, char
 		}
 		if (line[0] != '>') {	/* Trouble */
 			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: No segment header found [line %" PRIu64 "]\n", rec_no);
-			exit (GMT_RUNTIME_ERROR);
+			GMT_exit (GMT, GMT_RUNTIME_ERROR);
 		}
 		n_items = sscanf (&line[2], "%s %d %s %d %s %s", trk[0], &year[0], trk[1], &year[1], info[0], info[1]);
 		for (k = 0; k < strlen (trk[0]); k++) if (trk[0][k] == '.') trk[0][k] = '\0';
@@ -1762,11 +1765,11 @@ uint64_t x2sys_read_coe_dbase (struct GMT_CTRL *GMT, struct X2SYS_INFO *S, char
 			else {
 				if (gmt_verify_expectations (GMT, GMT_IS_ABSTIME, gmt_scanf (GMT, start[k], GMT_IS_ABSTIME, &P[p].start[k]), start[k])) {
 					GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: Header time specification tstart%d (%s) in wrong format [line %" PRIu64 "]\n", (k+1), start[k], rec_no);
-					exit (GMT_RUNTIME_ERROR);
+					GMT_exit (GMT, GMT_RUNTIME_ERROR);
 				}
 				if (gmt_verify_expectations (GMT, GMT_IS_ABSTIME, gmt_scanf (GMT, stop[k], GMT_IS_ABSTIME, &P[p].stop[k]), stop[k])) {
 					GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: Header time specification tstop%d (%s) in wrong format [line %" PRIu64 "]\n", (k+1), stop[k], rec_no);
-					exit (GMT_RUNTIME_ERROR);
+					GMT_exit (GMT, GMT_RUNTIME_ERROR);
 				}
 			}
 			P[p].dist[k] = dist[k];
@@ -1807,7 +1810,7 @@ uint64_t x2sys_read_coe_dbase (struct GMT_CTRL *GMT, struct X2SYS_INFO *S, char
 					P[p].COE[k].data[i][COE_T] = GMT->session.d_NaN;
 				else if (gmt_verify_expectations (GMT, GMT_IS_ABSTIME, gmt_scanf (GMT, t_txt[i], GMT_IS_ABSTIME, &P[p].COE[k].data[i][COE_T]), t_txt[i])) {
 					GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Error: Time specification t%d (%s) in wrong format [line %" PRIu64 "]\n", (i+1), t_txt[i], rec_no);
-					exit (GMT_RUNTIME_ERROR);
+					GMT_exit (GMT, GMT_RUNTIME_ERROR);
 				}
 			}
 			if (!two_values) {	/* Modify z to return the two values at the crossover point */
@@ -1925,7 +1928,7 @@ int x2sys_get_tracknames (struct GMT_CTRL *GMT, struct GMT_OPTION *options, char
 	/* Strip off any extensions */
 
 	for (i = 0; i < A; i++) {
-		if ((p = strchr (file[i], '.')) != NULL)
+		if ((p = strrchr (file[i], '.')) != NULL)
 			file[i][(size_t)(p-file[i])] = '\0';
 	}
 
@@ -1964,7 +1967,7 @@ void x2sys_get_corrtable (struct GMT_CTRL *GMT, struct X2SYS_INFO *S, char *ctab
 		sprintf (path, "%s/%s/%s_corrections.txt", X2SYS_HOME, S->TAG, S->TAG);
 		if (access (path, R_OK)) {
 			GMT_Report (GMT->parent, GMT_MSG_NORMAL, "No default X2SYS Correction table (%s) for %s found!\n", path, S->TAG);
-			exit (GMT_FILE_NOT_FOUND);
+			GMT_exit (GMT, GMT_FILE_NOT_FOUND);
 		}
 		ctable = path;
 	}
@@ -2003,5 +2006,5 @@ void x2sys_get_corrtable (struct GMT_CTRL *GMT, struct X2SYS_INFO *S, char *ctab
 	x2sys_free_list (GMT, aux_name, n_aux);
 	if (!missing) MGD77_Parse_Corrtable (GMT, ctable, trk_name, (unsigned int)ntracks, n_cols, col_name, 0, CORR);
 	x2sys_free_list (GMT, col_name, n_cols);
-	if (missing) exit (GMT_RUNTIME_ERROR);
+	if (missing) GMT_exit (GMT, GMT_RUNTIME_ERROR);
 }
